@@ -7,7 +7,7 @@ our $VERSION;
 
 use XSLoader;
 BEGIN {
-    $VERSION = '0.07';
+    $VERSION = '0.08';
     XSLoader::load(__PACKAGE__, $VERSION);
 }
 
@@ -30,7 +30,7 @@ Cookie::XS - HTTP Cookie parser in C
 
 =head1 VERSION
 
-This document describes Cookie::XS 0.07 released on March 6, 2008.
+This document describes Cookie::XS 0.08 released on March 20, 2008.
 
 =head1 SYNOPSIS
 
@@ -71,6 +71,36 @@ We currently provide 2 static methods, C<parse> and C<fetch>. They work mostly t
 
 We'll implement some cookie dump methods in the near future.
 
+=over
+
+=item C<< $ref = Cookie::XS->parse($raw_cookie) >>
+
+Parses C<$raw_cookie> and returns the reference of a hash of arrays. The keys
+of the hash are cookie variables' names while the values of the hash are lists of cookie variable's values.
+
+There is a length limit on the C<$raw_cookie>. If C<$raw_cookie> is longer than 4 KB (i.e. 4 * 1024 bytes, excluding the trailing '\0'), the overflowing part will be truncated.
+
+Also note that, C<fetch> does not assume any encoding on the cookie values. It just decodes the encoded entries verbatim and treat them as plain "binary" stuff.
+
+=item C<< $ref = Cookie::XS->fetch() >>
+
+Reads the raw cookie from the C<HTTP_COOKIE> and C<COOKIE> environments
+(which are usually set by HTTP servers like lighttd or apache) and then
+parses the value using the C<parse> method and finally returns the
+results.
+
+=back
+
+=head1 TODO
+
+=over
+
+=item *
+
+Removing trailing spaces in cookie values.
+
+=back
+
 =head1 SOURCE CONTROL
 
 For the very latest version of this module, check out the source from
